@@ -257,13 +257,8 @@ class WizardBricksStep extends Component {
                     bricksList[2].host_bricks[index].logicalSize = JSON.stringify(arbiterBrickSize * 10)
                 }
                 else{
-                    if (this.props.ansibleWizardType === "setup" && bricksList[2].host_bricks[index].name === "engine") {
-                        bricksList[2].host_bricks[index].size = "100"
-                        bricksList[2].host_bricks[index].logicalSize = "1000"
-                    } else {
-                        bricksList[2].host_bricks[index].size = "500"
-                        bricksList[2].host_bricks[index].logicalSize = "5000"
-                    }
+                    bricksList[2].host_bricks[index].size = (bricksList[0].host_bricks[index].size).toString(10)
+                    bricksList[2].host_bricks[index].logicalSize = (bricksList[0].host_bricks[index].size * 10).toString(10)
                 }
                 bricksHaveChanged = true
             }
@@ -671,7 +666,6 @@ class WizardBricksStep extends Component {
         const that = this
         let isVdoSupported = false
         let is_same_device = this.isAllDeviceSame()
-
         this.state.bricksList[this.state.selectedHost.hostIndex].host_bricks.forEach(function (brick, index) {
             if(brick.is_vdo_supported){
               isVdoSupported = true
@@ -726,7 +720,7 @@ class WizardBricksStep extends Component {
                 </div>
                 }
                 <form className="form-horizontal">
-                    <div className="panel-heading ansible-wizard-section-title">
+                    <div id="raidInformation" className="panel-heading ansible-wizard-section-title">
                         <h3 className="panel-title">Raid Information <span className="fa fa-lg fa-info-circle"
                             title="Enter your hardware RAID configuration details. This information will be used to align brick's LVM configuration with underlying RAID configuration for better I/O performance"></span>
                         </h3>
@@ -734,7 +728,7 @@ class WizardBricksStep extends Component {
                     <div className="form-group">
                         <label className="col-md-3 control-label">Raid Type</label>
                         <div className="col-md-2">
-                            <Selectbox optionList={raidTypes}
+                            <Selectbox id="raidType" optionList={raidTypes}
                                 selectedOption={this.state.raidConfig.raidType}
                                 callBack={(e) => this.handleRaidConfigUpdate("raidType", e)}
                                 />
@@ -768,13 +762,19 @@ class WizardBricksStep extends Component {
                         <div className="form-group">
                           <label className="col-md-2 control-label">Select Host</label>
                           <div className="col-md-4">
-                            {
-                              (this.state.hostTypes.length <= 0) ? null :
+                            { (this.state.hostTypes.length > 0 && !this.state.glusterModel.isSingleNode) &&
                               <Selectbox optionList={this.state.hostTypes}
                                 selectedOption={this.state.selectedHost.hostName}
                                 callBack={(e) => this.handleSelectedHostUpdate(e)}
                                 />
                             }
+                            { (this.state.hostTypes.length > 0 && this.state.glusterModel.isSingleNode) &&
+                              <Selectbox optionList={this.state.hostTypes}
+                                selectedOption={this.state.selectedHost.hostName}
+                                callBack={(e) => this.handleSelectedHostUpdate(e)}
+                                disabled="true"
+                                />
+                            }
                           </div>
                         </div>
                         <hr />
@@ -878,6 +878,9 @@ WizardBricksStep.propTypes = {
 }
 
 const BrickRow = ({hostIndex, enabledFields, hostArbiterVolumes, brick, index, errorMsgs, changeCallBack, deleteCallBack, ansibleWizardType}) => {
+    let deviceId = "device" + (index + 1)
+    let sizeId = "size" + (index + 1)
+    let logicalSizeId = "logicalSizeId" + (index + 1)
     let deleteButton = true;
     if(ansibleWizardType === "setup" || ansibleWizardType === "expand_volume") {
       deleteButton = false
@@ -911,7 +914,7 @@ const BrickRow = ({hostIndex, enabledFields, hostArbiterVolumes, brick, index, e
             </td>
             <td className="col-md-1">
                 <div className={device}>
-                    <input type="text" placeholder="device name"
+                    <input id={deviceId} type="text" placeholder="device name"
                         title="Name of the storage device (e.g sdb) which will be used to create brick"
                         className="form-control"
                         value={brick.device}
@@ -923,7 +926,7 @@ const BrickRow = ({hostIndex, enabledFields, hostArbiterVolumes, brick, index, e
             </td>
             <td className="col-md-1">
                 <div className={size}>
-                    <input type="number" className="form-control"
+                    <input id={sizeId} type="number" className="form-control"
                         value={brick.size}
                         onChange={(e) => changeCallBack(index, "size", e.target.value)}
                         disabled={(enabledFields.indexOf('size') >= 0 || hostArbiterVolumes.indexOf(brick.name) >= 0 ) ? false : true}
@@ -949,16 +952,17 @@ const BrickRow = ({hostIndex, enabledFields, hostArbiterVolumes, brick, index, e
                 </div>
             </td>
             <td className="col-md-1" className="col-md-1" style={brick.isVdoSupported ? {} : { display: 'none' }}>
-                <input type="checkbox" className="ansible-wizard-thinp-checkbox" title="Configure dedupe & compression using VDO."
+                <input id="vdoCheckBox" type="checkbox" className="ansible-wizard-thinp-checkbox" title="Configure dedupe & compression using VDO."
                     checked={brick.is_vdo_supported}
                     onChange={(e) => changeCallBack(index, "is_vdo_supported", e.target.checked, brick)}
                     />
             </td>
             <td className="col-md-1" style={brick.is_vdo_supported ? {} : { display: 'none' }}>
                 <div className={logicalSize}>
-                    <input type="number" className="form-control" title="Default logical size will be ten times of brick size."
+                    <input id={logicalSizeId} type="number" className="form-control" title="Default logical size will be ten times of brick size."
                         value={brick.logicalSize}
                         onChange={(e) => changeCallBack(index, "logicalSize", e.target.value)}
+                        disabled="true"
                         />
                     {errorMsgs && errorMsgs.logicalSize && <span className="help-block">{errorMsgs.logicalSize}</span>}
                 </div>
